/**
 * H5+ SQLite数据库操作.
 * @param {String} db_name 数据库名称.
 * @param {String} version 数据库版本.
 * @param {String} description 数据库描述.
 * @param {Number} size 数据库大小.
 */
    var DB = function(db_name, version, description, size) {
	var _db = openDatabase(db_name, version, description, size);
	return {
		/**
		 * 执行sql语句 返回影响条数
		 * @param {String} sql SQL语句.
		 * @param {Array} param 参数.
		 * @param {Function} callback 回调函数.
		 */
		execute: function(sql, param, callback) {
			if(!param) {
				param = [];
			} else if(typeof param == "function") {
				callback = param;
				param = [];
			}
			this.query(sql, param, function(result) {
				if(typeof callback == "function") {
					callback(result.rowsAffected);
				}
			});
		},
		/** 
		 * 执行sql，回调返回sql查询对象 
		 * 查询时，有数据返回数组，无数据返回0 
		 * 增删改时：返回int，影响条数 
		 * void query( string[, function]) 
		 * void query( string[, array[, function]]) 
		 */
		query: function(sql, param, callback) {
			if(!param) {
				param = [];
			} else if(typeof param == "function") {
				callback = param;
				param = [];
			}
			var self = this;
			_db.transaction(function(tx) {
				tx.executeSql(sql, param, function(tx, result) {
					if(typeof callback == "function") {
						callback(result);
					}
				}, self.onfail);
			})
		},
		/** 
		 * 插入，回调返回last id 
		 * void insert( string, object[, function]) 
		 */
		insert: function(table, data, callback) {
			if(typeof data != 'object' && typeof callback == 'function') {
				callback(0);
			}
			var k = [];
			var v = [];
			var param = [];
			for(var i in data) {
				console.log(i);
				k.push(i);
				v.push('?');
				param.push(data[i]);
			}
			var sql = "INSERT INTO " + table + "(" + k.join(',') + ")VALUES(" + v.join(',') + ")";
			this.query(sql, param, function(result) {
				if(typeof callback == 'function') {
					callback(result.insertId);
				}
			});
		},
		/** 
		 * 修改，回调返回影响条数 
		 * void update( string, object[, string[, function]]) 
		 * void update( string, object[, string[, array[, function]]]) 
		 */
		update: function(table, data, where, param, callback) {
			//参数处理  
			if(!param) {
				param = [];
			} else if(typeof param == 'function') {
				callback = param;
				param = [];
			}

			var set_info = this.mkWhere(data);
			for(var i = set_info.param.length - 1; i >= 0; i--) {
				param.unshift(set_info.param[i]);
			}
			var sql = "UPDATE " + table + " SET " + set_info.sql;
			if(where) {
				sql += " WHERE " + where;
			}

			this.query(sql, param, function(result) {
				if(typeof callback == 'function') {
					callback(result.rowsAffected);
				}
			});
		},
		/** 
		 * 删除 
		 * void toDelete( string, string[, function]]) 
		 * void toDelete( string, string[, array[, function]]) 
		 */
		toDelete: function(table, where, param, callback) {
			//参数处理  
			if(!param) {
				param = [];
			} else if(typeof param == 'function') {
				callback = param;
				param = [];
			}

			var sql = "DELETE FROM " + table + " WHERE " + where;
			this.query(sql, param, function(result) {
				if(typeof callback == 'function') {
					callback(result.rowsAffected);
				}
			});
		},
		/** 
		 * 查询，回调返回结果集数组 
		 * void fetch_all( string[, function] ) 
		 * void fetch_all( string[, param[, function]] ) 
		 */
		fetch: function(sql, param, callback) {
			//参数处理  
			if(!param) {
				param = [];
			} else if(typeof param == 'function') {
				callback = param;
				param = [];
			}

			this.query(sql, param, function(result) {
				if(typeof callback == 'function') {
					var out = [];
					if(result.rows.length) {
						for(var i = 0; i < result.rows.length; i++) {
							out.push(result.rows.item(i));
						}
					}
					callback(out);
				}
			});
		},
		/** 
		 * 查询表的信息 
		 * table_name: 表名称，支持 % *， 
		 */
		showTables: function(table_name, callback) {
			this.fetch("select * from sqlite_master where type='table' and name like ?", [table_name], callback);
		},
		/** 
		 * 组装查询条件 
		 */
		mkWhere: function(data) {
			var arr = [];
			var param = [];
			if(typeof data === 'object') {
				for(var i in data) {
					arr.push(i + "=?");
					param.push(data[i]);
					console.log('data.i:' + i);
				}
			}
			return {
				sql: arr.join(' AND '),
				param: param
			};
		},

		/**  
		 * 错误处理 
		 */
		onfail: function(tx, e) {
			console.info('SQL ERROR: ' + e.message);
		}
	}
}