//--------------------------------表单验证
/*****策略对象,根据需求添加******/
var strategies = {
	isNonEmpty: function ( value,errorMsg ) {  //不为空
		if (value === '') {
			return errorMsg;
		}
	},
	minNumber: function (value, num, errorMsg) {  //限制最小数字
		if (!value || (Number(value) <= Number(num)) ) {
			return errorMsg;
		}
	},
	minLength: function ( value, length,errorMsg ) {  //限制最小长度
		if ( value.length < length ) {
			return errorMsg;
		}
	},
	isPhone: function ( value,errorMsg ) {  //手机号码格式
		if ( !/(^\d{11}$)/.test( value ) ) {
			return errorMsg;
		}
	},
	isSfz: function ( value,errorMsg ) {  //手机号码格式
		if ( !/^(\d{18}|\d{17}[x,X])$/.test( value ) ) {
			return errorMsg;
		}
	},
	isMinDate: function ( value, errorMsg ) {  //不允许小于当前日期
		var reg=new RegExp("-","g"); 
		value=value.replace(reg,"/");
		var ndate = new Date(value).getTime();
		if (ndate < +new Date) {
			return errorMsg;
		}
	},
	isPassword:function(value,errorMsg){//密码强度数字和字母6到19位之间
		if(!/(?![0-9]+$)(?![a-zA-Z]+$)[0-9A-Za-z]{6,18}$/.test(value)){
			return errorMsg;
		}
	}
}

/*****Validator类******/
var Validator = function () {
	this.cache = [];
}

Validator.prototype.add = function ( value,rules ) {
	var self = this;
	for (var i = 0,rule; rule = rules[i++]; ) {
		(function (rule) {
			var startegyAry = rule.strategy.split(":");
			var errorMsg = rule.errorMsg;
			
			self.cache.push(function () {
				var strategy = startegyAry.shift();
				startegyAry.unshift( value );
				startegyAry.push( errorMsg );
				return strategies[ strategy ].apply( this, startegyAry );
			});
		})(rule)
	}
};

Validator.prototype.start = function () {
	for (var i = 0, validataFunc; validataFunc = this.cache[i++]; ) {
		var errorMsg = validataFunc();
		if ( errorMsg ) {
			return errorMsg;
		}
	}
}



/*******例。客户添加校验-在各自页面********/
////配置校验内容
//var validataFunc = function () {
//	//1.创建一个validator对象
//	var validator = new Validator();  
//	
//	//2.添加一些校验内容
//	validator.add( "testVal", [{ //用户名不为空并且长度不小于6
//		strategy: 'isNonEmpty',  
//		errorMsg: '用户名不能为空'
//	},{
//		strategy: 'minLength:6',  
//		errorMsg: '长度不能小于6'
//	}]);
//	
//	validator.add( "tPass", [{ //密码长度不小于8
//		strategy: 'minLength:8',  
//		errorMsg: '长度不能小于8'
//	}]);
//	
//	var errorMsg = validator.start();
//	return errorMsg;
//}
//
////提交时进行校验
//var btn = document.getElementById("btn");
//btn.onclick = function () {
//	var errorMsg = validataFunc();
//	if ( errorMsg ) {
//		alert( errorMsg );
//		return
//	}
//	alert("全部校验通过");
//}

